<a name="eevp4"></a>

# 1、中国人民大学

中国北京市境内公办高校<br />中国人民大学（Renmin University of China），简称“[人大](https://baike.baidu.com/item/%E4%BA%BA%E5%A4%A7/9685680?fromModule=lemma_inlink)”，位于北京市海淀区中关村大街59号 [158]，系[教育部直属高校](https://baike.baidu.com/item/%E6%95%99%E8%82%B2%E9%83%A8%E7%9B%B4%E5%B1%9E%E9%AB%98%E6%A0%A1/7999306?fromModule=lemma_inlink)，[教育部](https://baike.baidu.com/item/%E6%95%99%E8%82%B2%E9%83%A8/239078?fromModule=lemma_inlink)与[北京市](https://baike.baidu.com/item/%E5%8C%97%E4%BA%AC%E5%B8%82/126069?fromModule=lemma_inlink)共建，位列国家“[双一流](https://baike.baidu.com/item/%E5%8F%8C%E4%B8%80%E6%B5%81/19394525?fromModule=lemma_inlink)”、 [112]“[211工程](https://baike.baidu.com/item/211%E5%B7%A5%E7%A8%8B/203547?fromModule=lemma_inlink)”、“[985工程](https://baike.baidu.com/item/985%E5%B7%A5%E7%A8%8B/1077915?fromModule=lemma_inlink)”，为[世界大学联盟](https://baike.baidu.com/item/%E4%B8%96%E7%95%8C%E5%A4%A7%E5%AD%A6%E8%81%94%E7%9B%9F/4564339?fromModule=lemma_inlink)、[国际应用科技开发协作网](https://baike.baidu.com/item/%E5%9B%BD%E9%99%85%E5%BA%94%E7%94%A8%E7%A7%91%E6%8A%80%E5%BC%80%E5%8F%91%E5%8D%8F%E4%BD%9C%E7%BD%91/23519898?fromModule=lemma_inlink)、[亚太国际教育协会](https://baike.baidu.com/item/%E4%BA%9A%E5%A4%AA%E5%9B%BD%E9%99%85%E6%95%99%E8%82%B2%E5%8D%8F%E4%BC%9A/8650942?fromModule=lemma_inlink)、[亚洲校园](https://baike.baidu.com/item/%E4%BA%9A%E6%B4%B2%E6%A0%A1%E5%9B%AD/1768750?fromModule=lemma_inlink) [140]、[京港大学联盟](https://baike.baidu.com/item/%E4%BA%AC%E6%B8%AF%E5%A4%A7%E5%AD%A6%E8%81%94%E7%9B%9F/22488054?fromModule=lemma_inlink)成员，入选国家“[强基计划](https://baike.baidu.com/item/%E5%BC%BA%E5%9F%BA%E8%AE%A1%E5%88%92/24266392?fromModule=lemma_inlink)”、“[111计划](https://baike.baidu.com/item/111%E8%AE%A1%E5%88%92/10958807?fromModule=lemma_inlink)”、“[2011计划](https://baike.baidu.com/item/2011%E8%AE%A1%E5%88%92/2913309?fromModule=lemma_inlink)”、[卓越法律人才教育培养计划](https://baike.baidu.com/item/%E5%8D%93%E8%B6%8A%E6%B3%95%E5%BE%8B%E4%BA%BA%E6%89%8D%E6%95%99%E8%82%B2%E5%9F%B9%E5%85%BB%E8%AE%A1%E5%88%92/9781317?fromModule=lemma_inlink)、[卓越农林人才教育培养计划](https://baike.baidu.com/item/%E5%8D%93%E8%B6%8A%E5%86%9C%E6%9E%97%E4%BA%BA%E6%89%8D%E6%95%99%E8%82%B2%E5%9F%B9%E5%85%BB%E8%AE%A1%E5%88%92/15906214?fromModule=lemma_inlink)、[国家建设高水平大学公派研究生项目](https://baike.baidu.com/item/%E5%9B%BD%E5%AE%B6%E5%BB%BA%E8%AE%BE%E9%AB%98%E6%B0%B4%E5%B9%B3%E5%A4%A7%E5%AD%A6%E5%85%AC%E6%B4%BE%E7%A0%94%E7%A9%B6%E7%94%9F%E9%A1%B9%E7%9B%AE/819876?fromModule=lemma_inlink)、[新工科研究与实践项目](https://baike.baidu.com/item/%E6%96%B0%E5%B7%A5%E7%A7%91%E7%A0%94%E7%A9%B6%E4%B8%8E%E5%AE%9E%E8%B7%B5%E9%A1%B9%E7%9B%AE/22833448?fromModule=lemma_inlink)、[中国政府奖学金来华留学生接收院校](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E6%94%BF%E5%BA%9C%E5%A5%96%E5%AD%A6%E9%87%91%E6%9D%A5%E5%8D%8E%E7%95%99%E5%AD%A6%E7%94%9F%E6%8E%A5%E6%94%B6%E9%99%A2%E6%A0%A1/15447730?fromModule=lemma_inlink)，是一所以[人文社会科学](https://baike.baidu.com/item/%E4%BA%BA%E6%96%87%E7%A4%BE%E4%BC%9A%E7%A7%91%E5%AD%A6/10708177?fromModule=lemma_inlink)为主的综合性研究型[全国重点大学](https://baike.baidu.com/item/%E5%85%A8%E5%9B%BD%E9%87%8D%E7%82%B9%E5%A4%A7%E5%AD%A6/2154589?fromModule=lemma_inlink)。 [1-7]<br />学校前身是1937年成立的[陕北公学](https://baike.baidu.com/item/%E9%99%95%E5%8C%97%E5%85%AC%E5%AD%A6/9571977?fromModule=lemma_inlink)，以及[华北联合大学](https://baike.baidu.com/item/%E5%8D%8E%E5%8C%97%E8%81%94%E5%90%88%E5%A4%A7%E5%AD%A6/9540608?fromModule=lemma_inlink)和北方大学、华北大学。 [3]1949年12月16日，[中央人民政府政务院](https://baike.baidu.com/item/%E4%B8%AD%E5%A4%AE%E4%BA%BA%E6%B0%91%E6%94%BF%E5%BA%9C%E6%94%BF%E5%8A%A1%E9%99%A2/14704524?fromModule=lemma_inlink)通过了《关于成立中国人民大学的决定》。1950年10月3日，以[华北大学](https://baike.baidu.com/item/%E5%8D%8E%E5%8C%97%E5%A4%A7%E5%AD%A6/9571421?fromModule=lemma_inlink)为基础合并组建的中国人民大学正式开学，成为新中国创办的第一所新型正规大学。1954年，被确定为以社会科学为主的[综合大学](https://baike.baidu.com/item/%E7%BB%BC%E5%90%88%E5%A4%A7%E5%AD%A6/230720?fromModule=lemma_inlink)和首批全国重点大学；1960年，被确定为综合性[全国重点大学](https://baike.baidu.com/item/%E5%85%A8%E5%9B%BD%E9%87%8D%E7%82%B9%E5%A4%A7%E5%AD%A6/2154589?fromModule=lemma_inlink)；2017年入选国家“双一流”建设名单。 [8]<br />学校设有39个学院，另设有体育部、[继续教育学院](https://baike.baidu.com/item/%E7%BB%A7%E7%BB%AD%E6%95%99%E8%82%B2%E5%AD%A6%E9%99%A2/4584543?fromModule=lemma_inlink)、深圳研究院等；开设本科专业85个；有[博士后流动站](https://baike.baidu.com/item/%E5%8D%9A%E5%A3%AB%E5%90%8E%E6%B5%81%E5%8A%A8%E7%AB%99/719793?fromModule=lemma_inlink)21个，[一级学科](https://baike.baidu.com/item/%E4%B8%80%E7%BA%A7%E5%AD%A6%E7%A7%91/8792001?fromModule=lemma_inlink)[博士学位授权点](https://baike.baidu.com/item/%E5%8D%9A%E5%A3%AB%E5%AD%A6%E4%BD%8D%E6%8E%88%E6%9D%83%E7%82%B9/3470279?fromModule=lemma_inlink)22个，一级学科[硕士学位授权点](https://baike.baidu.com/item/%E7%A1%95%E5%A3%AB%E5%AD%A6%E4%BD%8D%E6%8E%88%E6%9D%83%E7%82%B9/24571992?fromModule=lemma_inlink)37个；拥有8个国家重点一级学科，8个国家重点[二级学科](https://baike.baidu.com/item/%E4%BA%8C%E7%BA%A7%E5%AD%A6%E7%A7%91/3696644?fromModule=lemma_inlink)；图书馆收藏纸质图书436.7万余册；有专任教师1970人；在学学生28649人，其中全日制本科生11768人、硕士生11837人、博士生5044人。
<a name="AuFTt"></a>

## 1.1、办学条件

<a name="B0m3j"></a>

### 1.1.1、院系专业

截至2023年1月，学校下设有5个学部、26个教学单位（23个学院、3个研究院）、85个本科专业，另设有体育部、继续教育学院、培训学院、苏州校区、深圳研究院等。 [3]

| **学部** |                                                                                                                   **学院**                                                                                                                    |                **本科专业**                 |
|--------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------|
| 人文学部   | [中国人民大学哲学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%93%B2%E5%AD%A6%E9%99%A2/8742916?fromModule=lemma_inlink)                                                                                 | 哲学、伦理学、宗教学                              |
| 人文学部   | [中国人民大学文学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E6%96%87%E5%AD%A6%E9%99%A2/8741210?fromModule=lemma_inlink)                                                                                 | 汉语言文学                                   |
| 人文学部   | [中国人民大学历史学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%8E%86%E5%8F%B2%E5%AD%A6%E9%99%A2/8743097?fromModule=lemma_inlink)                                                                       | 历史学                                     |
| 人文学部   | [中国人民大学国学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%9B%BD%E5%AD%A6%E9%99%A2/9227022?fromModule=lemma_inlink)                                                                                 | 中国哲学、中国古代文学、中国古代史、专门史                   |
| 人文学部   | [中国人民大学艺术学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E8%89%BA%E6%9C%AF%E5%AD%A6%E9%99%A2/8743024?fromModule=lemma_inlink)                                                                       | 绘画、艺术设计、音乐表演、美术学                        |
| 人文学部   | [中国人民大学外国语学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%A4%96%E5%9B%BD%E8%AF%AD%E5%AD%A6%E9%99%A2/4453773?fromModule=lemma_inlink)                                                             | 英语、俄语、日语、德语、法语、西班牙语 [62]                |
| 社会学部   | [中国人民大学新闻学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E6%96%B0%E9%97%BB%E5%AD%A6%E9%99%A2/4453550?fromModule=lemma_inlink)                                                                       | 新闻学、广播电视新闻学、广告学、传播学                     |
| 社会学部   | [中国人民大学农业与农村发展学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%86%9C%E4%B8%9A%E4%B8%8E%E5%86%9C%E6%9D%91%E5%8F%91%E5%B1%95%E5%AD%A6%E9%99%A2/6848469?fromModule=lemma_inlink)                     | 农业经济管理、农村区域发展                           |
| 社会学部   | [中国人民大学社会与人口学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E7%A4%BE%E4%BC%9A%E4%B8%8E%E4%BA%BA%E5%8F%A3%E5%AD%A6%E9%99%A2/4452913?fromModule=lemma_inlink)                                         | 社会学、社会工作、公共事业管理（人口与社会管理方向）              |
| 社会学部   | [中国人民大学公共管理学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%85%AC%E5%85%B1%E7%AE%A1%E7%90%86%E5%AD%A6%E9%99%A2/10646613?fromModule=lemma_inlink)                                                  | 行政管理、土地资源管理、城市管理                        |
| 社会学部   | [中国人民大学信息资源管理学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E4%BF%A1%E6%81%AF%E8%B5%84%E6%BA%90%E7%AE%A1%E7%90%86%E5%AD%A6%E9%99%A2/8740539?fromModule=lemma_inlink)                               | 档案学、信息资源管理、信息管理与信息系统（政务信息管理方向）          |
| 经济学部   | [中国人民大学经济学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E7%BB%8F%E6%B5%8E%E5%AD%A6%E9%99%A2/4452232?fromModule=lemma_inlink)                                                                       | 经济学、国际经济与贸易                             |
| 经济学部   | [中国人民大学财政金融学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E8%B4%A2%E6%94%BF%E9%87%91%E8%9E%8D%E5%AD%A6%E9%99%A2/6834937?fromModule=lemma_inlink)                                                   | 财政学、金融学、税务、保险学、金融工程、信用管理 [63]           |
| 经济学部   | [中国人民大学应用经济学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%BA%94%E7%94%A8%E7%BB%8F%E6%B5%8E%E5%AD%A6%E9%99%A2/24121352?fromModule=lemma_inlink)                                                  | 国民经济管理、能源经济学                            |
| 经济学部   | [中国人民大学统计学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E7%BB%9F%E8%AE%A1%E5%AD%A6%E9%99%A2/6835109?fromModule=lemma_inlink)                                                                       | 统计学、风险管理与精算学                            |
| 经济学部   | [中国人民大学商学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%95%86%E5%AD%A6%E9%99%A2/7011272?fromModule=lemma_inlink)                                                                                 | 工商管理、市场营销、会计学、财务管理、管理科学、贸易经济            |
| 经济学部   | [中国人民大学劳动人事学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%8A%B3%E5%8A%A8%E4%BA%BA%E4%BA%8B%E5%AD%A6%E9%99%A2/1302750?fromModule=lemma_inlink)                                                   | 劳动与社会保障、人力资源管理、劳动关系                     |
| 经济学部   | [中国人民大学中法学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E4%B8%AD%E6%B3%95%E5%AD%A6%E9%99%A2/10962034?fromModule=lemma_inlink)（苏州）                                                                  | 金融学、国民经济管理、法语                           |
| 经济学部   | [中国人民大学国际学院（苏州研究院）](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%9B%BD%E9%99%85%E5%AD%A6%E9%99%A2%EF%BC%88%E8%8B%8F%E5%B7%9E%E7%A0%94%E7%A9%B6%E9%99%A2%EF%BC%89/7560289?fromModule=lemma_inlink) | 金融风险管理、汉语国际教育 [119]                     |
| 法政学部   | [中国人民大学法学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E6%B3%95%E5%AD%A6%E9%99%A2/4452575?fromModule=lemma_inlink)                                                                                 | 法学                                      |
| 法政学部   | [中国人民大学马克思主义学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E9%A9%AC%E5%85%8B%E6%80%9D%E4%B8%BB%E4%B9%89%E5%AD%A6%E9%99%A2/7570418?fromModule=lemma_inlink)                                         | 中国革命史与中国共产党党史                           |
| 法政学部   | [中国人民大学国际关系学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%9B%BD%E9%99%85%E5%85%B3%E7%B3%BB%E5%AD%A6%E9%99%A2/4453134?fromModule=lemma_inlink)                                                   | 国际政治、外交学、政治学与行政学                        |
| 法政学部   | [中国人民大学知识产权学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E7%9F%A5%E8%AF%86%E4%BA%A7%E6%9D%83%E5%AD%A6%E9%99%A2/22039879?fromModule=lemma_inlink)                                                  | -                                       |
| 法政学部   | [中国人民大学律师学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E5%BE%8B%E5%B8%88%E5%AD%A6%E9%99%A2/569861?fromModule=lemma_inlink)                                                                        | -                                       |
| 法政学部   | [中国人民大学丝路学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E4%B8%9D%E8%B7%AF%E5%AD%A6%E9%99%A2/22453246?fromModule=lemma_inlink)（苏州）                                                                  | “当代中国研究”硕士项目 [121]                      |
| 法政学部   | 中国人民大学中共党史党建学院                                                                                                                                                                                                                              | -                                       |
| 法政学部   | 中国人民大学纪检监察学院                                                                                                                                                                                                                                | -                                       |
| 理工学部   | [中国人民大学环境学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E7%8E%AF%E5%A2%83%E5%AD%A6%E9%99%A2/8743060?fromModule=lemma_inlink)                                                                       | 环境科学、公共事业管理、环境工程                        |
| 理工学部   | [中国人民大学信息学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E4%BF%A1%E6%81%AF%E5%AD%A6%E9%99%A2/6124608?fromModule=lemma_inlink)                                                                       | 计算机科学与技术、信息管理与信息系统、信息安全、软件工程、数据科学与大数据技术 |
| 理工学部   | [中国人民大学理学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E7%90%86%E5%AD%A6%E9%99%A2/61857195?fromModule=lemma_inlink)                                                                                | 物理学、材料物理、化学、应用心理学                       |
| 理工学部   | [中国人民大学数学学院](https://baike.baidu.com/item/%E4%B8%AD%E5%9B%BD%E4%BA%BA%E6%B0%91%E5%A4%A7%E5%AD%A6%E6%95%B0%E5%AD%A6%E5%AD%A6%E9%99%A2/22697259?fromModule=lemma_inlink)                                                                      | 数学与应用数学 [67]、数据计算及应用                    |

<a name="nY1ct"></a>

### 1.1.2、师资力量

截至2023年1月，学校有专任教师1970人，其中教授784人，副教授762人。学校有全国高等教育领域唯二的“人民教育家”国家荣誉称号获得者卫兴华教授和高铭暄教授；有19人担任第八届国务院学位委员会学科评议组成员，47人入选新一届教育部教学指导委员会委员，共有128人入选国家重大人才工程、505人享受国务院政府特殊津贴、117人入选国家重大青年人才工程。

|         **类别**         |                                      **名单**                                       |
|------------------------|-----------------------------------------------------------------------------------|
| “万人计划”教学名师             | 韩大元                                                                               |
| “万人计划”哲学社会科学领军人才       | 王利明、洪大用、张宇、张雷声、刘建军、徐兆仁、杨光斌、郭庆旺、蔡雯、张新宝                                             |
| “万人计划”青年拔尖人才           | 臧峰宇、竺效、叶光亮、季威（不完全名单）                                                              |
| 国家级教学团队                | 宪法学与行政法学教学团队、工商管理核心课程教学团队、“西方文艺理论史”教学团队、民商法教学团队、财政学教学团队、金融学国际化培养模式创新教学团队、外国哲学教学团队 |
| 国家级教学名师                | 方福前、韩大元、陈岳、龙翼飞、王珊、张征                                                              |
| “百千万人才工程”国家级人选         | 汪昌云、刘元春、岳希明、韩大元、张杰、张雷声、吴晓求、杨光斌、杨瑞龙、卢仲毅、张宇、郭庆旺、刘元春、王利明、洪大用（不完全名单）                  |
| 国家杰出青年科学基金获得者          | 汪昌云、卢仲毅、毛基业、洪大用（不完全名单）                                                            |
| 国家“有突出贡献的中青年专家”        | 汪昌云、刘元春、岳希明（不完全名单）                                                                |
| 教育部哲学社会科学“跨世纪优秀人才培养计划” | 韩大元、王利明                                                                           |
| 教育部“高校青年教师奖”           | 韩大元，胡百精。（不完全名单）                                                                   |
| 教育部“新世纪优秀人才支持计划”       | 韩大元、汪昌云、任剑涛、张新宝、张志铭、刘建军、杨光斌、杨瑞龙、郝立新、王轶、朱信凯（不完全名单） [68-76]                         |

<a name="nzaCy"></a>

### 1.1.3、学科建设

截至2023年1月，学校有8个国家重点一级学科，8个国家重点二级学科，在人文社会科学领域均居全国第一。学校设有学士学位专业85个、硕士学位授权二级学科169个、博士学位授权二级学科141个，拥有硕士学位授权一级学科35个，博士学位授权一级学科23个，拥有硕士专业学位授权类别26个，博士专业学位授权类别1个，博士后科研流动站21个。在教育部2017年公布的全国第四轮学科评估结果中，中国人民大学获评A类学科的总数共14个，其中理论经济学、应用经济学、法学、社会学、新闻传播学、统计学、工商管理、公共管理、马克思主义理论获评A+，政治学、哲学获评A，图书情报与档案管理、中国史、中国语言文学获评A-，A+学科数量位列全国高校第四；在教育部首轮“双一流”建设评价中，学校14个一流学科表现优异，继续入选第二轮“双一流”建设学科名单。 [3]<br />在2012年中国教育部学科评估中，人大的理论经济学、应用经济学、法学类、政治学、社会学、新闻传播学、[统计学](https://baike.baidu.com/item/%E7%BB%9F%E8%AE%A1%E5%AD%A6/1175?fromModule=lemma_inlink)、工商管理、公共管理等9个学科排名中国第一；哲学、马克思主义理论、农林经济管理3个一级学科排名中国第二，图书情报与档案管理排名中国第三，中国史排名中国第四。 [77-78]

|   **类别**    |                                                                                             **名称**                                                                                             |
|-------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 博士后流动站      | 理论经济学、应用经济学、法学、政治学、社会学、中国语言文学、新闻传播学、中国史、物理学、考古学、世界史、统计学、计算机科学与技术、工商管理、农林经济管理、公共管理、图书情报与档案管理、哲学、马克思主义理论                                                                                         |
| 博士学位一级学科授权点 | 哲学、理论经济学、应用经济学、法学、政治学、社会学、马克思主义理论、中国语言文学、外国语言文学、新闻传播学、考古学、中国史、世界史、数学、统计学、工商管理、计算机科学与技术、农林经济管理、公共管理、图书馆情报与档案管理                                                                                  |
| 博士专业学位授权类别  | 电子信息                                                                                                                                                                                           |
| 硕士学位一级学科授权点 | 哲学、理论经济学、应用经济学、法学、政治学、社会学、马克思主义理论、中国语言文学、外国语言文学、新闻传播学、考古学、中国史、世界史、数学、统计学、工商管理、计算机科学与技术、农林经济管理、公共管理、图书馆情报档案管理、美术学、音乐与舞蹈学、戏剧与影视学、公共卫生与预防医学、管理科学与工程、软件工程、食品科学与工程、系统科学、环境工程、生态学、地理学、化学、物理学、心理学、教育学 |
| 硕士专业学位授权类别  | 金融、应用统计、税务、国际商务、保险、资产评估、法律、社会工作、汉语国际教育、应用心理、翻译、新闻与传播、文物与博物馆、电子信息、资源与环境、农业、工商管理、公共管理、会计、图书情报、艺术                                                                                                 |
| “双一流”建设学科   | 哲学、理论经济学、应用经济学、法学、政治学、社会学、马克思主义理论、新闻传播学、中国史、统计学、工商管理、农林经济管理、公共管理、图书情报与档案管理                                                                                                                     |
| 国家重点一级学科    | 哲学、理论经济学、应用经济学、法学、社会学、马克思主义理论、新闻传播学、工商管理                                                                                                                                                       |
| 国家重点二级学科    | 中共党史、国际政治、文艺学、中国古代史、中国近现代史、农业经济管理、行政管理、档案学                                                                                                                                                     |
| 北京市重点一级学科   | 政治学、中国语言文学、中国史、农林经济管理、图书馆情报与档案管理                                                                                                                                                               |
| 北京市重点二级学科   | 计算机应用技术、教育经济与管理、社会保障、土地资源管理                                                                                                                                                                    |
| 北京市重点交叉学科   | 农村发展管理 [2] [72] [79-81] [155]                                                                                                                                                                  |

<a name="tmCNx"></a>

## 1.2、学校领导

<a name="BL546"></a>

### 1.2.1、现任领导

|           **职务**           |                                                                                                                                                                                   **姓名**                                                                                                                                                                                   |
|----------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 党委书记                       | [张东刚](https://baike.baidu.com/item/%E5%BC%A0%E4%B8%9C%E5%88%9A/78441?fromModule=lemma_inlink)                                                                                                                                                                                                                                                                              |
| 党委副书记、校长                   | [林尚立](https://baike.baidu.com/item/%E6%9E%97%E5%B0%9A%E7%AB%8B/6883251?fromModule=lemma_inlink)                                                                                                                                                                                                                                                                            |
| 党委副书记、纪委书记、国家监委驻中国人民大学监察专员 | [吴付来](https://baike.baidu.com/item/%E5%90%B4%E4%BB%98%E6%9D%A5/5032969?fromModule=lemma_inlink)                                                                                                                                                                                                                                                                            |
| 党委副书记                      | [郑水泉](https://baike.baidu.com/item/%E9%83%91%E6%B0%B4%E6%B3%89/5454976?fromModule=lemma_inlink)、[齐鹏飞](https://baike.baidu.com/item/%E9%BD%90%E9%B9%8F%E9%A3%9E/4258582?fromModule=lemma_inlink)                                                                                                                                                                            |
| 党委常委、常务副校长                 | [朱信凯](https://baike.baidu.com/item/%E6%9C%B1%E4%BF%A1%E5%87%AF/2929795?fromModule=lemma_inlink)                                                                                                                                                                                                                                                                            |
| 党委常委、副校长                   | [王轶](https://baike.baidu.com/item/%E7%8E%8B%E8%BD%B6/53454?fromModule=lemma_inlink)、[王易](https://baike.baidu.com/item/%E7%8E%8B%E6%98%93/15100642?fromModule=lemma_inlink)、[冯仕政](https://baike.baidu.com/item/%E5%86%AF%E4%BB%95%E6%94%BF/2643887?fromModule=lemma_inlink)、[郑新业](https://baike.baidu.com/item/%E9%83%91%E6%96%B0%E4%B8%9A/4145180?fromModule=lemma_inlink) |
| 党委常委、组织部部长、统战部部长           | [青格勒图](https://baike.baidu.com/item/%E9%9D%92%E6%A0%BC%E5%8B%92%E5%9B%BE/62090534?fromModule=lemma_inlink)                                                                                                                                                                                                                                                                 |

<a name="iakF3"></a>

### 1.2.2、历任领导

|                                            **历任校长**                                             |                   |                                             **历任书记**                                             |                   |
|-------------------------------------------------------------------------------------------------|-------------------|--------------------------------------------------------------------------------------------------|-------------------|
| 姓名                                                                                              | 任期                | 姓名                                                                                               | 任期                |
| [刘伟](https://baike.baidu.com/item/%E5%88%98%E4%BC%9F/3145686?fromModule=lemma_inlink)           | （2015.11-2022.8）  | [靳诺](https://baike.baidu.com/item/%E9%9D%B3%E8%AF%BA/8932744?fromModule=lemma_inlink)            | （2013.4—2021.11）  |
| [陈雨露](https://baike.baidu.com/item/%E9%99%88%E9%9B%A8%E9%9C%B2/16586?fromModule=lemma_inlink)   | （2011.11—2015.10） | [程天权](https://baike.baidu.com/item/%E7%A8%8B%E5%A4%A9%E6%9D%83/9671511?fromModule=lemma_inlink)  | （2001.02—2013.04） |
| [纪宝成](https://baike.baidu.com/item/%E7%BA%AA%E5%AE%9D%E6%88%90/5741030?fromModule=lemma_inlink) | （2000.09—2011.11） | [马绍孟](https://baike.baidu.com/item/%E9%A9%AC%E7%BB%8D%E5%AD%9F/4163058?fromModule=lemma_inlink)  | （1994.06—2001.02） |
| [李文海](https://baike.baidu.com/item/%E6%9D%8E%E6%96%87%E6%B5%B7/4852023?fromModule=lemma_inlink) | （1994.06—2000.09） | [李文海](https://baike.baidu.com/item/%E6%9D%8E%E6%96%87%E6%B5%B7/4852023?fromModule=lemma_inlink)  | （1987.10—1994.06） |
| [黄达](https://baike.baidu.com/item/%E9%BB%84%E8%BE%BE/23526?fromModule=lemma_inlink)             | （1991.11—1994.06） | [李焕昌](https://baike.baidu.com/item/%E6%9D%8E%E7%84%95%E6%98%8C/62563545?fromModule=lemma_inlink) | （1985.09—1987.10） |
| [袁宝华](https://baike.baidu.com/item/%E8%A2%81%E5%AE%9D%E5%8D%8E/1462255?fromModule=lemma_inlink) | （1985.06—1991.11） | [袁宝华](https://baike.baidu.com/item/%E8%A2%81%E5%AE%9D%E5%8D%8E/1462255?fromModule=lemma_inlink)  | （1985.09—1988.05） |
| [郭影秋](https://baike.baidu.com/item/%E9%83%AD%E5%BD%B1%E7%A7%8B/2010144?fromModule=lemma_inlink) | （1983.06—1985.10） | [张腾霄](https://baike.baidu.com/item/%E5%BC%A0%E8%85%BE%E9%9C%84/5746931?fromModule=lemma_inlink)  | （1983.06—1985.09） |
| [成仿吾](https://baike.baidu.com/item/%E6%88%90%E4%BB%BF%E5%90%BE/998634?fromModule=lemma_inlink)  | （1983.06—1984.05） | [成仿吾](https://baike.baidu.com/item/%E6%88%90%E4%BB%BF%E5%90%BE/998634?fromModule=lemma_inlink)   | （1978.07—1983.06） |
| 成仿吾                                                                                             | （1978.07—1983.06） | [郭影秋](https://baike.baidu.com/item/%E9%83%AD%E5%BD%B1%E7%A7%8B/2010144?fromModule=lemma_inlink)  | （1978.07—1983.06） |
| [吴玉章](https://baike.baidu.com/item/%E5%90%B4%E7%8E%89%E7%AB%A0/2221?fromModule=lemma_inlink)    | （1950.02—1966.12） | 郭影秋                                                                                              | （1963.04—1969.09） |
|                                                                                                 |                   | [胡锡奎](https://baike.baidu.com/item/%E8%83%A1%E9%94%A1%E5%A5%8E/6120805?fromModule=lemma_inlink)  | （1956.10—1963.04） |
|                                                                                                 |                   | 崔耀先                                                                                              | （1952.11—1956.10） |
|                                                                                                 |                   | 胡锡奎                                                                                              | （1951.12—1952.11） |
|                                                                                                 |                   | [阎子元](https://baike.baidu.com/item/%E9%98%8E%E5%AD%90%E5%85%83/5826239?fromModule=lemma_inlink)  | （1950.02—1951.12） |
|                                                                                                 |                   | 胡锡奎                                                                                              | （1950.11—1956.10） |

<a name="f0QZo"></a>

## 1.3、知名校友

中共十八大中，中国人民大学18名校友当选中央委员、9名校友当选中央候补委员、10名校友当选中央纪委委员，入选校友人数位居中国高校第一位。 [108]

|  **政界**  |       [刘鹤](https://baike.baidu.com/item/%E5%88%98%E9%B9%A4/70324?fromModule=lemma_inlink)        |         [尤权](https://baike.baidu.com/item/%E5%B0%A4%E6%9D%83/2164991?fromModule=lemma_inlink)          |
|----------|--------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------|
|          | [刘延东](https://baike.baidu.com/item/%E5%88%98%E5%BB%B6%E4%B8%9C/116908?fromModule=lemma_inlink)   | [马凯](https://baike.baidu.com/item/%E9%A9%AC%E5%87%AF/2595511?fromModule=lemma_inlink)                  |
|          | [杨白冰](https://baike.baidu.com/item/%E6%9D%A8%E7%99%BD%E5%86%B0/1538412?fromModule=lemma_inlink)  | [肖扬](https://baike.baidu.com/item/%E8%82%96%E6%89%AC/116719?fromModule=lemma_inlink)                   |
|          | [骆惠宁](https://baike.baidu.com/item/%E9%AA%86%E6%83%A0%E5%AE%81/3511667?fromModule=lemma_inlink)  | [韩长赋](https://baike.baidu.com/item/%E9%9F%A9%E9%95%BF%E8%B5%8B/10938808?fromModule=lemma_inlink)       |
|          | [于伟国](https://baike.baidu.com/item/%E4%BA%8E%E4%BC%9F%E5%9B%BD/6960654?fromModule=lemma_inlink)  | [肖钢](https://baike.baidu.com/item/%E8%82%96%E9%92%A2/17469?fromModule=lemma_inlink)                    |
|          | [朱小丹](https://baike.baidu.com/item/%E6%9C%B1%E5%B0%8F%E4%B8%B9/6799922?fromModule=lemma_inlink)  | [孟学农](https://baike.baidu.com/item/%E5%AD%9F%E5%AD%A6%E5%86%9C/2895415?fromModule=lemma_inlink)        |
|          | [徐光春](https://baike.baidu.com/item/%E5%BE%90%E5%85%89%E6%98%A5/625304?fromModule=lemma_inlink)   | [李泽民](https://baike.baidu.com/item/%E6%9D%8E%E6%B3%BD%E6%B0%91/4915721?fromModule=lemma_inlink)        |
|          | [陈焕友](https://baike.baidu.com/item/%E9%99%88%E7%84%95%E5%8F%8B/75562?fromModule=lemma_inlink)    | [何竹康](https://baike.baidu.com/item/%E4%BD%95%E7%AB%B9%E5%BA%B7/5754620?fromModule=lemma_inlink)        |
|          | [芮杏文](https://baike.baidu.com/item/%E8%8A%AE%E6%9D%8F%E6%96%87/5668251?fromModule=lemma_inlink)  | [潘功胜](https://baike.baidu.com/item/%E6%BD%98%E5%8A%9F%E8%83%9C/647820?fromModule=lemma_inlink)         |
|          | [张勇](https://baike.baidu.com/item/%E5%BC%A0%E5%8B%87/3126593?fromModule=lemma_inlink)            | [张肖](https://baike.baidu.com/item/%E5%BC%A0%E8%82%96/5801918?fromModule=lemma_inlink)                  |
|          | [高昌礼](https://baike.baidu.com/item/%E9%AB%98%E6%98%8C%E7%A4%BC/5514549?fromModule=lemma_inlink)  | [刘登银](https://baike.baidu.com/item/%E5%88%98%E7%99%BB%E9%93%B6/14216900?fromModule=lemma_inlink) [169] |
| **文艺传媒** | [艾青](https://baike.baidu.com/item/%E8%89%BE%E9%9D%92/173395?fromModule=lemma_inlink)             | [王小波](https://baike.baidu.com/item/%E7%8E%8B%E5%B0%8F%E6%B3%A2/6673?fromModule=lemma_inlink)           |
|          | [张洁](https://baike.baidu.com/item/%E5%BC%A0%E6%B4%81/1305?fromModule=lemma_inlink)               | [梁衡](https://baike.baidu.com/item/%E6%A2%81%E8%A1%A1/2002337?fromModule=lemma_inlink)                  |
|          | [毛高田](https://baike.baidu.com/item/%E6%AF%9B%E9%AB%98%E7%94%B0/1297174?fromModule=lemma_inlink)  | [郭兰英](https://baike.baidu.com/item/%E9%83%AD%E5%85%B0%E8%8B%B1/31567?fromModule=lemma_inlink)          |
|          | 张万象                                                                                              | [邵华泽](https://baike.baidu.com/item/%E9%82%B5%E5%8D%8E%E6%B3%BD/4661721?fromModule=lemma_inlink)        |
|          | [杨伟光](https://baike.baidu.com/item/%E6%9D%A8%E4%BC%9F%E5%85%89/55670?fromModule=lemma_inlink)    | [曾子墨](https://baike.baidu.com/item/%E6%9B%BE%E5%AD%90%E5%A2%A8/1781614?fromModule=lemma_inlink)        |
|          | [高菡](https://baike.baidu.com/item/%E9%AB%98%E8%8F%A1/58145350?fromModule=lemma_inlink)           |                                                                                                        |
| **工商界**  | [刘强东](https://baike.baidu.com/item/%E5%88%98%E5%BC%BA%E4%B8%9C/8015087?fromModule=lemma_inlink)  | [张磊](https://baike.baidu.com/item/%E5%BC%A0%E7%A3%8A/8864724?fromModule=lemma_inlink)                  |
|          | [段永平](https://baike.baidu.com/item/%E6%AE%B5%E6%B0%B8%E5%B9%B3/6041736?fromModule=lemma_inlink)  | [陈小宪](https://baike.baidu.com/item/%E9%99%88%E5%B0%8F%E5%AE%AA/1748382?fromModule=lemma_inlink)        |
|          | [刘明辉](https://baike.baidu.com/item/%E5%88%98%E6%98%8E%E8%BE%89/24126911?fromModule=lemma_inlink) | [宋丽萍](https://baike.baidu.com/item/%E5%AE%8B%E4%B8%BD%E8%90%8D/37619?fromModule=lemma_inlink)          |
|          | [杨鶤](https://baike.baidu.com/item/%E6%9D%A8%E9%B6%A4/5184163?fromModule=lemma_inlink)            | [黄光裕](https://baike.baidu.com/item/%E9%BB%84%E5%85%89%E8%A3%95/216703?fromModule=lemma_inlink)         |
|          | [易小迪](https://baike.baidu.com/item/%E6%98%93%E5%B0%8F%E8%BF%AA/10638173?fromModule=lemma_inlink) | [汪静](https://baike.baidu.com/item/%E6%B1%AA%E9%9D%99/1196106?fromModule=lemma_inlink)                  |
|          | [乔虹](https://baike.baidu.com/item/%E4%B9%94%E8%99%B9/55724?fromModule=lemma_inlink)              | 何迪                                                                                                     |
|          | [汪涛](https://baike.baidu.com/item/%E6%B1%AA%E6%B6%9B/5095511?fromModule=lemma_inlink)            | [陈国栋](https://baike.baidu.com/item/%E9%99%88%E5%9B%BD%E6%A0%8B/4201127?fromModule=lemma_inlink)        |
|          | [王群](https://baike.baidu.com/item/%E7%8E%8B%E7%BE%A4/2810181?fromModule=lemma_inlink)            | [韩敬远](https://baike.baidu.com/item/%E9%9F%A9%E6%95%AC%E8%BF%9C/5707418?fromModule=lemma_inlink)        |
|          | [谢文](https://baike.baidu.com/item/%E8%B0%A2%E6%96%87/10104?fromModule=lemma_inlink)              | 陈贤丰                                                                                                    |
| **科教界**  | [吴玉章](https://baike.baidu.com/item/%E5%90%B4%E7%8E%89%E7%AB%A0/2221?fromModule=lemma_inlink)     | [成仿吾](https://baike.baidu.com/item/%E6%88%90%E4%BB%BF%E5%90%BE/998634?fromModule=lemma_inlink)         |
|          | [高鸿业](https://baike.baidu.com/item/%E9%AB%98%E9%B8%BF%E4%B8%9A/5730721?fromModule=lemma_inlink)  | [范文澜](https://baike.baidu.com/item/%E8%8C%83%E6%96%87%E6%BE%9C/119479?fromModule=lemma_inlink)         |
|          | [艾思奇](https://baike.baidu.com/item/%E8%89%BE%E6%80%9D%E5%A5%87/1213379?fromModule=lemma_inlink)  | [何思敬](https://baike.baidu.com/item/%E4%BD%95%E6%80%9D%E6%95%AC/2460929?fromModule=lemma_inlink)        |
|          | [苗力田](https://baike.baidu.com/item/%E8%8B%97%E5%8A%9B%E7%94%B0/3239061?fromModule=lemma_inlink)  | [石峻](https://baike.baidu.com/item/%E7%9F%B3%E5%B3%BB/1253345?fromModule=lemma_inlink)                  |
|          | [查瑞传](https://baike.baidu.com/item/%E6%9F%A5%E7%91%9E%E4%BC%A0/4651252?fromModule=lemma_inlink)  | [刘铮](https://baike.baidu.com/item/%E5%88%98%E9%93%AE/8980564?fromModule=lemma_inlink)                  |
|          | [戴世光](https://baike.baidu.com/item/%E6%88%B4%E4%B8%96%E5%85%89/5743475?fromModule=lemma_inlink)  | [宋涛](https://baike.baidu.com/item/%E5%AE%8B%E6%B6%9B/39242?fromModule=lemma_inlink)                    |
|          | [陈共](https://baike.baidu.com/item/%E9%99%88%E5%85%B1/10569224?fromModule=lemma_inlink)           | [黄达](https://baike.baidu.com/item/%E9%BB%84%E8%BE%BE/23526?fromModule=lemma_inlink)                    |
|          | [周骏](https://baike.baidu.com/item/%E5%91%A8%E9%AA%8F/6694454?fromModule=lemma_inlink)            | [吴汉东](https://baike.baidu.com/item/%E5%90%B4%E6%B1%89%E4%B8%9C/2227265?fromModule=lemma_inlink)        |
|          | [洪道德](https://baike.baidu.com/item/%E6%B4%AA%E9%81%93%E5%BE%B7/4502573?fromModule=lemma_inlink)  | [冯其庸](https://baike.baidu.com/item/%E5%86%AF%E5%85%B6%E5%BA%B8/1356456?fromModule=lemma_inlink)        |
|          | [傅德印](https://baike.baidu.com/item/%E5%82%85%E5%BE%B7%E5%8D%B0/983353?fromModule=lemma_inlink)   | [梁美芬](https://baike.baidu.com/item/%E6%A2%81%E7%BE%8E%E8%8A%AC/8075132?fromModule=lemma_inlink)        |
|          | [储殷](https://baike.baidu.com/item/%20%E5%82%A8%E6%AE%B7/22605173?fromModule=lemma_inlink) [154]  |                                                                                                        |
|          | [周其仁](https://baike.baidu.com/item/%E5%91%A8%E5%85%B6%E4%BB%81/2711572?fromModule=lemma_inlink)  | [许小年](https://baike.baidu.com/item/%E8%AE%B8%E5%B0%8F%E5%B9%B4/7316764?fromModule=lemma_inlink)        |
|          | [张保生](https://baike.baidu.com/item/%E5%BC%A0%E4%BF%9D%E7%94%9F/6181576?fromModule=lemma_inlink)  | [郑雄伟](https://baike.baidu.com/item/%E9%83%91%E9%9B%84%E4%BC%9F/2716177?fromModule=lemma_inlink)        |
| **体育界**  | [郭晶晶](https://baike.baidu.com/item/%E9%83%AD%E6%99%B6%E6%99%B6/965689?fromModule=lemma_inlink)   | [吴敏霞](https://baike.baidu.com/item/%E5%90%B4%E6%95%8F%E9%9C%9E/15707?fromModule=lemma_inlink)          |
|          | [何姿](https://baike.baidu.com/item/%E4%BD%95%E5%A7%BF/2706983?fromModule=lemma_inlink)            | [陈若琳](https://baike.baidu.com/item/%E9%99%88%E8%8B%A5%E7%90%B3/10958884?fromModule=lemma_inlink)       |
|          | [秦凯](https://baike.baidu.com/item/%E7%A7%A6%E5%87%AF/26546?fromModule=lemma_inlink)              | [胡佳](https://baike.baidu.com/item/%E8%83%A1%E4%BD%B3/15324?fromModule=lemma_inlink)                    |
|          | [林跃](https://baike.baidu.com/item/%E6%9E%97%E8%B7%83/12059?fromModule=lemma_inlink)              | [火亮](https://baike.baidu.com/item/%E7%81%AB%E4%BA%AE/6555066?fromModule=lemma_inlink)                  |
|          | [王军霞](https://baike.baidu.com/item/%E7%8E%8B%E5%86%9B%E9%9C%9E/3149246?fromModule=lemma_inlink)  | [李娜](https://baike.baidu.com/item/%E6%9D%8E%E5%A8%9C/5285?fromModule=lemma_inlink)                     |
|          | [李婷](https://baike.baidu.com/item/%E6%9D%8E%E5%A9%B7/22429?fromModule=lemma_inlink)              | [梁艳](https://baike.baidu.com/item/%E6%A2%81%E8%89%B3/10841867?fromModule=lemma_inlink)                 |
|          | [彭勃](https://baike.baidu.com/item/%E5%BD%AD%E5%8B%83/51668?fromModule=lemma_inlink)              | -                                                                                                      |

<a name="P81D5"></a>

# <br />

